/*
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2005 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

### File Specific:
   main-programmer: David Hasenfratz, Stefan Lienhard
   co-programmer:
*/

#include "movie_entity.h"

#include "media_container.h"
#include "load_param.h"
#include "factory.h"
#include "material.h"

#include "network_game_manager.h"
#include "converter.h"

using namespace std;

CREATE_FACTORY(MovieEntity, CL_MOVIE_ENTITY);

/**
 *  standard constructor
 */
MovieEntity::MovieEntity (const TiXmlElement* root)
{
  this->setClassID(CL_MOVIE_ENTITY, "MovieEntity");

  media_container = new MediaContainer("/home/david/Desktop/Crash.mpg");

  this->material = new Material;
  this->material->setDiffuseMap("maps/radialTransparency.png");

  this->toList(OM_COMMON);

  this->loadParams(root);

  counter = 0;
  timer = 0;
  fps = media_container->getFPS();
}

/**
 *  standard destructor
 */
MovieEntity::~MovieEntity ()
{
  delete this->material;
  delete this->media_container;
}

void MovieEntity::loadParams(const TiXmlElement* root)
{
  static_cast<WorldEntity*>(this)->loadParams(root);
}

void MovieEntity::loadMovie(const char* filename)
{

}

/**
 *  this method is called every frame
 * @param time: the time in seconds that has passed since the last tick

   Handle all stuff that should update with time inside this method (movement, animation, etc.)
 */
void MovieEntity::tick(float time)
{
  timer += time;

  if(counter != fps * timer)
  {
    counter = fps * timer;

    if (counter >= media_container->getFrameCount())
    {
      timer = 0;
      counter = 0;
    }
  }
}


/**
 *  the entity is drawn onto the screen with this function

   This is a central function of an entity: call it to let the entity painted to the screen. Just override this function with whatever you want to be drawn.
 */
void MovieEntity::draw() const
{

  glPushMatrix();
  glTranslatef (this->getAbsCoor ().x,
                this->getAbsCoor ().y,
                this->getAbsCoor ().z);

  this->material->select();
  glBindTexture(GL_TEXTURE_2D, media_container->getFrameTexture(counter));

  glBegin(GL_QUADS);
    // Front Face
    glTexCoord2f(1.0f, 1.0f); glVertex3f(-1.0f, -1.0f,  1.0f);  // Bottom Left Of The Texture and Quad
    glTexCoord2f(0.0f, 1.0f); glVertex3f( 1.0f, -1.0f,  1.0f);  // Bottom Right Of The Texture and Quad
    glTexCoord2f(0.0f, 0.0f); glVertex3f( 1.0f,  1.0f,  1.0f);  // Top Right Of The Texture and Quad
    glTexCoord2f(1.0f, 0.0f); glVertex3f(-1.0f,  1.0f,  1.0f);  // Top Left Of The Texture and Quad
  glEnd();

  glPopMatrix();

}
